@@ -21,7 +21,6 @@ from osc_lib.cli import format_columns
 from osc_lib.cli import parseractions
 from osc_lib.command import command
 from osc_lib import utils
-import six
 
 from openstackclient.i18n import _
 
@@ -233,7 +232,7 @@ class ShowContainer(command.ShowOne):
         if 'properties' in data:
             data['properties'] = format_columns.DictColumn(data['properties'])
 
-        return zip(*sorted(six.iteritems(data)))
+        return zip(*sorted(data.items()))
 
 
 class UnsetContainer(command.Command):
